summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ChangeLog1
-rw-r--r--doc/de/autogen/user/weechat_commands.txt28
-rw-r--r--doc/en/autogen/user/weechat_commands.txt12
-rw-r--r--doc/fr/autogen/user/weechat_commands.txt12
-rw-r--r--doc/it/autogen/user/weechat_commands.txt32
-rw-r--r--doc/ja/autogen/user/weechat_commands.txt28
-rw-r--r--po/cs.po22
-rw-r--r--po/de.po24
-rw-r--r--po/es.po22
-rw-r--r--po/fr.po32
-rw-r--r--po/hu.po18
-rw-r--r--po/it.po24
-rw-r--r--po/ja.po24
-rw-r--r--po/pl.po24
-rw-r--r--po/pt_BR.po24
-rw-r--r--po/ru.po18
-rw-r--r--po/tr.po16
-rw-r--r--po/weechat.pot15
-rw-r--r--src/core/wee-command.c28
19 files changed, 234 insertions, 170 deletions
diff --git a/ChangeLog b/ChangeLog
index 5a7fe1e32..ec408f430 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -11,6 +11,7 @@ http://weechat.org/files/releasenotes/ReleaseNotes-devel.html[release notes]
== Version 0.4.3 (under dev)
+* core: rename options save/reset to add/del in command /layout
* core: add options weechat.look.buffer_auto_renumber and
weechat.look.buffer_position, add option "renumber" in command /buffer, add
bar item "buffer_last_number" (task #12766)
diff --git a/doc/de/autogen/user/weechat_commands.txt b/doc/de/autogen/user/weechat_commands.txt
index d149e198a..89b72fe2c 100644
--- a/doc/de/autogen/user/weechat_commands.txt
+++ b/doc/de/autogen/user/weechat_commands.txt
@@ -469,26 +469,26 @@ Beispiele:
----
[[command_weechat_layout]]
-[command]*`layout`* Layout für Buffer und Fenster speichern, anwenden oder zurücksetzen::
+[command]*`layout`* manage buffers/windows layouts::
----
-/layout save [<name>] [buffers|windows]
+/layout add [<name>] [buffers|windows]
apply [<name>] [buffers|windows]
leave
- reset [<name>] [buffers|windows]
+ del [<name>] [buffers|windows]
rename <name> <new_name>
- save: speichert das aktuelle Layout
- apply: das gespeicherte Layout anwenden
- leave: belässt das aktuelle Layout (es wird kein Layout aktualisiert)
- reset: das gespeicherte Layout, mit Buffern und/oder Fenstern, zurücksetzen
- (falls Buffer und Fenster zurückgesetzt werden, dann wird das Layout entfernt)
- rename: ein Layout umbenennen
- name: Name unter welchem das Layout gesichert werden soll (Standardlayout lautet "default")
-buffers: speichert bzw. verwendet nur Buffer (Reihenfolge der Buffer)
-windows: speichert bzw. verwendet nur Fenster (Buffer welche im jeweiligen Fenster dargestellt werden)
-
-Wird der Befehl ohne Argumente aufgerufen wird das gespeicherte Layout dargestellt.
+ add: create a layout using the current buffers/windows
+ apply: apply saved layout
+ leave: leave current layout (does not update any layout)
+ del: delete buffers and/or windows in a saved layout
+ (if neither "buffers" nor "windows" is given after the name, the layout is deleted)
+ rename: rename a layout
+ name: name for saved layout (default is "default")
+buffers: save/apply only buffers (order of buffers)
+windows: save/apply only windows (buffer displayed by each window)
+
+Without argument, this command displays saved layouts.
----
[[command_weechat_mouse]]
diff --git a/doc/en/autogen/user/weechat_commands.txt b/doc/en/autogen/user/weechat_commands.txt
index a4b7922b1..3b875e726 100644
--- a/doc/en/autogen/user/weechat_commands.txt
+++ b/doc/en/autogen/user/weechat_commands.txt
@@ -469,20 +469,20 @@ Examples:
----
[[command_weechat_layout]]
-[command]*`layout`* save/apply/reset layout for buffers and windows::
+[command]*`layout`* manage buffers/windows layouts::
----
-/layout save [<name>] [buffers|windows]
+/layout add [<name>] [buffers|windows]
apply [<name>] [buffers|windows]
leave
- reset [<name>] [buffers|windows]
+ del [<name>] [buffers|windows]
rename <name> <new_name>
- save: save current layout
+ add: create a layout using the current buffers/windows
apply: apply saved layout
leave: leave current layout (does not update any layout)
- reset: reset buffers and/or windows in a saved layout
- (if both buffers and windows are reset, the layout is removed)
+ del: delete buffers and/or windows in a saved layout
+ (if neither "buffers" nor "windows" is given after the name, the layout is deleted)
rename: rename a layout
name: name for saved layout (default is "default")
buffers: save/apply only buffers (order of buffers)
diff --git a/doc/fr/autogen/user/weechat_commands.txt b/doc/fr/autogen/user/weechat_commands.txt
index 1641ae557..2887e5102 100644
--- a/doc/fr/autogen/user/weechat_commands.txt
+++ b/doc/fr/autogen/user/weechat_commands.txt
@@ -469,20 +469,20 @@ Exemples:
----
[[command_weechat_layout]]
-[command]*`layout`* sauver/appliquer/réinitialiser la disposition des tampons et fenêtres::
+[command]*`layout`* gestion des dispositions de tampons/fenêtres::
----
-/layout save [<nom>] [buffers|windows]
+/layout add [<nom>] [buffers|windows]
apply [<nom>] [buffers|windows]
leave
- reset [<nom>] [buffers|windows]
+ del [<nom>] [buffers|windows]
rename <nom> <nouveau_nom>
- save: sauver la disposition courante
+ add: créer une disposition avec les tampons/fenêtres courants
apply: appliquer une disposition sauvegardée
leave: quitter la disposition courante (ne met à jour aucune disposition)
- reset: réinitialiser les tampons et/ou fenêtres dans une disposition sauvegardée
- (si les tampons et fenêtres sont réinitialisées ensemble, la disposition est supprimée)
+ del: supprimer les tampons et/ou fenêtres dans une disposition sauvegardée
+ (si ni "buffers" ni "windows" n'est donné après le nom, la disposition est supprimée)
rename: renommer une disposition
nom: nom pour la disposition sauvegardée (par défaut "default")
buffers: sauver/appliquer seulement pour les tampons (ordre des tampons)
diff --git a/doc/it/autogen/user/weechat_commands.txt b/doc/it/autogen/user/weechat_commands.txt
index bcab907d7..dfb647f90 100644
--- a/doc/it/autogen/user/weechat_commands.txt
+++ b/doc/it/autogen/user/weechat_commands.txt
@@ -469,26 +469,26 @@ Esempi:
----
[[command_weechat_layout]]
-[command]*`layout`* salva/applica/ripristina il layout per i buffer e le finestre::
+[command]*`layout`* manage buffers/windows layouts::
----
-/layout save [<nome>] [buffers|windows]
+/layout add [<name>] [buffers|windows]
apply [<name>] [buffers|windows]
leave
- reset [<nome>] [buffers|windows]
- rename <nome> <nuovo_nome>
-
- save: salva il layout corrente
- apply: applica il layout salvato
- leave: lascia il layout corrente (non applica nessun layout
- reset: ripristina buffer e/o finestre in un layout salvato
- (se sia i buffer che le finestre vengono ripristinate, il layout viene rimosso)
- rename: rinomina un layout
- nome: nome per il layout salvato (per default è "default")
-buffers: salva/applica modifiche solo ai buffer (ordine dei buffer)
-windows: salva/applica modifiche solo alle finestre (buffer visualizzato da ogni finestra)
-
-Senza argomenti, il comando mostra i layout salvati.
+ del [<name>] [buffers|windows]
+ rename <name> <new_name>
+
+ add: create a layout using the current buffers/windows
+ apply: apply saved layout
+ leave: leave current layout (does not update any layout)
+ del: delete buffers and/or windows in a saved layout
+ (if neither "buffers" nor "windows" is given after the name, the layout is deleted)
+ rename: rename a layout
+ name: name for saved layout (default is "default")
+buffers: save/apply only buffers (order of buffers)
+windows: save/apply only windows (buffer displayed by each window)
+
+Without argument, this command displays saved layouts.
----
[[command_weechat_mouse]]
diff --git a/doc/ja/autogen/user/weechat_commands.txt b/doc/ja/autogen/user/weechat_commands.txt
index 78ad831fd..4ac89ec87 100644
--- a/doc/ja/autogen/user/weechat_commands.txt
+++ b/doc/ja/autogen/user/weechat_commands.txt
@@ -469,26 +469,26 @@ listdefault: デフォルトキーをリストアップ
----
[[command_weechat_layout]]
-[command]*`layout`* バッファとウィンドウのレイアウトを保存/適用/リセット::
+[command]*`layout`* manage buffers/windows layouts::
----
-/layout save [<name>] [buffers|windows]
+/layout add [<name>] [buffers|windows]
apply [<name>] [buffers|windows]
leave
- reset [<name>] [buffers|windows]
+ del [<name>] [buffers|windows]
rename <name> <new_name>
- save: 現在のレイアウトを保存
- apply: 保存されたレイアウトを適用
- leave: 現在のレイアウトを保持する (レイアウトを更新しない)
- reset: 保存されたレイアウトでバッファとウィンドウをリセット
- (バッファとウィンドウの両方がリセットされる場合、レイアウトは削除されます)
- rename: レイアウトのリネーム
- name: 保存されたレイアウトの名前 (初期状態は "default")
-buffers: バッファのみに対してレイアウトを保存/適用 (バッファの順番)
-windows: ウィンドウのみに対してレイアウトを保存/適用 (それぞれのウィンドウに表示されるバッファ)
-
-引数無しでは、保存されたレイアウトを表示します。
+ add: create a layout using the current buffers/windows
+ apply: apply saved layout
+ leave: leave current layout (does not update any layout)
+ del: delete buffers and/or windows in a saved layout
+ (if neither "buffers" nor "windows" is given after the name, the layout is deleted)
+ rename: rename a layout
+ name: name for saved layout (default is "default")
+buffers: save/apply only buffers (order of buffers)
+windows: save/apply only windows (buffer displayed by each window)
+
+Without argument, this command displays saved layouts.
----
[[command_weechat_mouse]]
diff --git a/po/cs.po b/po/cs.po
index 7daec1b4d..3bbd4c5a8 100644
--- a/po/cs.po
+++ b/po/cs.po
@@ -20,7 +20,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2013-12-11 21:18+0100\n"
+"POT-Creation-Date: 2013-12-13 12:43+0100\n"
"PO-Revision-Date: 2013-11-09 10:18+0100\n"
"Last-Translator: Jiri Golembiovsky <golemj@gmail.com>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -1717,23 +1717,25 @@ msgstr ""
" obnoví výchozí napojení pro klávesu alt-r:\n"
" /key reset meta-r"
-msgid "save/apply/reset layout for buffers and windows"
-msgstr "uložit/použít/resetovat rozložení bufferů a oken"
+#, fuzzy
+msgid "manage buffers/windows layouts"
+msgstr "řídit buffery"
#, fuzzy
msgid ""
-"save [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
-"|| reset [<name>] [buffers|windows] || rename <name> <new_name>"
+"add [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
+"|| del [<name>] [buffers|windows] || rename <name> <new_name>"
msgstr ""
"save [buffers|windows] || apply [buffers|windows] || reset [buffers|windows]"
#, fuzzy
msgid ""
-" save: save current layout\n"
+" add: create a layout using the current buffers/windows\n"
" apply: apply saved layout\n"
" leave: leave current layout (does not update any layout)\n"
-" reset: reset buffers and/or windows in a saved layout\n"
-" (if both buffers and windows are reset, the layout is removed)\n"
+" del: delete buffers and/or windows in a saved layout\n"
+" (if neither \"buffers\" nor \"windows\" is given after the name, "
+"the layout is deleted)\n"
" rename: rename a layout\n"
" name: name for saved layout (default is \"default\")\n"
"buffers: save/apply only buffers (order of buffers)\n"
@@ -9941,5 +9943,9 @@ msgstr ""
msgid "Constants"
msgstr ""
+#, fuzzy
+#~ msgid "manage layouts for buffers and windows"
+#~ msgstr "uložit/použít/resetovat rozložení bufferů a oken"
+
#~ msgid "set title for window (terminal for Curses GUI) with name and version"
#~ msgstr "nastaví titulek okna (terminálu pro Cruses GUI) s jménem a verzí"
diff --git a/po/de.po b/po/de.po
index 3a71dd1ab..a655e8c9b 100644
--- a/po/de.po
+++ b/po/de.po
@@ -22,7 +22,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat 0.4.3-dev\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2013-12-11 21:18+0100\n"
+"POT-Creation-Date: 2013-12-13 12:43+0100\n"
"PO-Revision-Date: 2013-11-20 15:12+0100\n"
"Last-Translator: Nils Görs <weechatter@arcor.de>\n"
"Language-Team: German <weechatter@arcor.de>\n"
@@ -1916,22 +1916,26 @@ msgstr ""
" /key bindctxt mouse @item(buffer_nicklist):button3 /msg nickserv info "
"${nick}"
-msgid "save/apply/reset layout for buffers and windows"
-msgstr "Layout für Buffer und Fenster speichern, anwenden oder zurücksetzen"
+#, fuzzy
+msgid "manage buffers/windows layouts"
+msgstr "Buffer verwalten"
+#, fuzzy
msgid ""
-"save [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
-"|| reset [<name>] [buffers|windows] || rename <name> <new_name>"
+"add [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
+"|| del [<name>] [buffers|windows] || rename <name> <new_name>"
msgstr ""
"save [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
"|| reset [<name>] [buffers|windows] || rename <name> <new_name>"
+#, fuzzy
msgid ""
-" save: save current layout\n"
+" add: create a layout using the current buffers/windows\n"
" apply: apply saved layout\n"
" leave: leave current layout (does not update any layout)\n"
-" reset: reset buffers and/or windows in a saved layout\n"
-" (if both buffers and windows are reset, the layout is removed)\n"
+" del: delete buffers and/or windows in a saved layout\n"
+" (if neither \"buffers\" nor \"windows\" is given after the name, "
+"the layout is deleted)\n"
" rename: rename a layout\n"
" name: name for saved layout (default is \"default\")\n"
"buffers: save/apply only buffers (order of buffers)\n"
@@ -10991,3 +10995,7 @@ msgstr "Type"
msgid "Constants"
msgstr "Konstanten"
+
+#, fuzzy
+#~ msgid "manage layouts for buffers and windows"
+#~ msgstr "Layout für Buffer und Fenster speichern, anwenden oder zurücksetzen"
diff --git a/po/es.po b/po/es.po
index 99934792e..dd2fa8cab 100644
--- a/po/es.po
+++ b/po/es.po
@@ -22,7 +22,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2013-12-11 21:18+0100\n"
+"POT-Creation-Date: 2013-12-13 12:43+0100\n"
"PO-Revision-Date: 2013-11-09 10:18+0100\n"
"Last-Translator: Elián Hanisch <lambdae2@gmail.com>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -1805,23 +1805,25 @@ msgstr ""
" /key bindctxt mouse @item(buffer_nicklist):button3 /msg nickserv info "
"${nick}"
-msgid "save/apply/reset layout for buffers and windows"
-msgstr "guardar/aplicar/reiniciar el esquema de las ventanas y buffers"
+#, fuzzy
+msgid "manage buffers/windows layouts"
+msgstr "gestionar los buffers"
#, fuzzy
msgid ""
-"save [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
-"|| reset [<name>] [buffers|windows] || rename <name> <new_name>"
+"add [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
+"|| del [<name>] [buffers|windows] || rename <name> <new_name>"
msgstr ""
"save [buffers|windows] || apply [buffers|windows] || reset [buffers|windows]"
#, fuzzy
msgid ""
-" save: save current layout\n"
+" add: create a layout using the current buffers/windows\n"
" apply: apply saved layout\n"
" leave: leave current layout (does not update any layout)\n"
-" reset: reset buffers and/or windows in a saved layout\n"
-" (if both buffers and windows are reset, the layout is removed)\n"
+" del: delete buffers and/or windows in a saved layout\n"
+" (if neither \"buffers\" nor \"windows\" is given after the name, "
+"the layout is deleted)\n"
" rename: rename a layout\n"
" name: name for saved layout (default is \"default\")\n"
"buffers: save/apply only buffers (order of buffers)\n"
@@ -10203,6 +10205,10 @@ msgstr "Tipo"
msgid "Constants"
msgstr "Constantes"
+#, fuzzy
+#~ msgid "manage layouts for buffers and windows"
+#~ msgstr "guardar/aplicar/reiniciar el esquema de las ventanas y buffers"
+
#~ msgid "set title for window (terminal for Curses GUI) with name and version"
#~ msgstr ""
#~ "define el título de la ventana (el terminal para la interfaz Curses) con "
diff --git a/po/fr.po b/po/fr.po
index 04199fd73..a5333230e 100644
--- a/po/fr.po
+++ b/po/fr.po
@@ -21,8 +21,8 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2013-12-11 21:18+0100\n"
-"PO-Revision-Date: 2013-12-11 21:18+0100\n"
+"POT-Creation-Date: 2013-12-13 12:43+0100\n"
+"PO-Revision-Date: 2013-12-13 12:44+0100\n"
"Last-Translator: Sebastien Helleu <flashcode@flashtux.org>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
"Language: fr\n"
@@ -1874,22 +1874,23 @@ msgstr ""
" /key bindctxt mouse @item(buffer_nicklist):button3 /msg nickserv info "
"${nick}"
-msgid "save/apply/reset layout for buffers and windows"
-msgstr "sauver/appliquer/réinitialiser la disposition des tampons et fenêtres"
+msgid "manage buffers/windows layouts"
+msgstr "gestion des dispositions de tampons/fenêtres"
msgid ""
-"save [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
-"|| reset [<name>] [buffers|windows] || rename <name> <new_name>"
+"add [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
+"|| del [<name>] [buffers|windows] || rename <name> <new_name>"
msgstr ""
-"save [<nom>] [buffers|windows] || apply [<nom>] [buffers|windows] || leave "
-"|| reset [<nom>] [buffers|windows] || rename <nom> <nouveau_nom>"
+"add [<nom>] [buffers|windows] || apply [<nom>] [buffers|windows] || leave || "
+"del [<nom>] [buffers|windows] || rename <nom> <nouveau_nom>"
msgid ""
-" save: save current layout\n"
+" add: create a layout using the current buffers/windows\n"
" apply: apply saved layout\n"
" leave: leave current layout (does not update any layout)\n"
-" reset: reset buffers and/or windows in a saved layout\n"
-" (if both buffers and windows are reset, the layout is removed)\n"
+" del: delete buffers and/or windows in a saved layout\n"
+" (if neither \"buffers\" nor \"windows\" is given after the name, "
+"the layout is deleted)\n"
" rename: rename a layout\n"
" name: name for saved layout (default is \"default\")\n"
"buffers: save/apply only buffers (order of buffers)\n"
@@ -1897,12 +1898,12 @@ msgid ""
"\n"
"Without argument, this command displays saved layouts."
msgstr ""
-" save: sauver la disposition courante\n"
+" add: créer une disposition avec les tampons/fenêtres courants\n"
" apply: appliquer une disposition sauvegardée\n"
" leave: quitter la disposition courante (ne met à jour aucune disposition)\n"
-" reset: réinitialiser les tampons et/ou fenêtres dans une disposition "
+" del: supprimer les tampons et/ou fenêtres dans une disposition "
"sauvegardée\n"
-" (si les tampons et fenêtres sont réinitialisées ensemble, la "
+" (si ni \"buffers\" ni \"windows\" n'est donné après le nom, la "
"disposition est supprimée)\n"
" rename: renommer une disposition\n"
" nom: nom pour la disposition sauvegardée (par défaut \"default\")\n"
@@ -10742,6 +10743,9 @@ msgstr "Type"
msgid "Constants"
msgstr "Constantes"
+#~ msgid "manage layouts for buffers and windows"
+#~ msgstr "gérer les dispositions des tampons et fenêtres"
+
#~ msgid "set title for window (terminal for Curses GUI) with name and version"
#~ msgstr ""
#~ "définit le titre de la fenêtre (terminal pour l'interface Curses) avec le "
diff --git a/po/hu.po b/po/hu.po
index 6d411e80b..71be6e8bf 100644
--- a/po/hu.po
+++ b/po/hu.po
@@ -20,7 +20,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2013-12-11 21:18+0100\n"
+"POT-Creation-Date: 2013-12-13 12:43+0100\n"
"PO-Revision-Date: 2013-11-09 10:18+0100\n"
"Last-Translator: Andras Voroskoi <voroskoi@frugalware.org>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -1525,20 +1525,22 @@ msgstr ""
" reset: billenzyűparancsok visszaállítása az eredeti értékekre és MINDEN "
"személyes hozzárendelés törlése (használja óvatosan!)"
-msgid "save/apply/reset layout for buffers and windows"
-msgstr ""
+#, fuzzy
+msgid "manage buffers/windows layouts"
+msgstr "pufferek kezelése"
msgid ""
-"save [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
-"|| reset [<name>] [buffers|windows] || rename <name> <new_name>"
+"add [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
+"|| del [<name>] [buffers|windows] || rename <name> <new_name>"
msgstr ""
msgid ""
-" save: save current layout\n"
+" add: create a layout using the current buffers/windows\n"
" apply: apply saved layout\n"
" leave: leave current layout (does not update any layout)\n"
-" reset: reset buffers and/or windows in a saved layout\n"
-" (if both buffers and windows are reset, the layout is removed)\n"
+" del: delete buffers and/or windows in a saved layout\n"
+" (if neither \"buffers\" nor \"windows\" is given after the name, "
+"the layout is deleted)\n"
" rename: rename a layout\n"
" name: name for saved layout (default is \"default\")\n"
"buffers: save/apply only buffers (order of buffers)\n"
diff --git a/po/it.po b/po/it.po
index 301f1cf35..b94b52c01 100644
--- a/po/it.po
+++ b/po/it.po
@@ -20,7 +20,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2013-12-11 21:18+0100\n"
+"POT-Creation-Date: 2013-12-13 12:43+0100\n"
"PO-Revision-Date: 2013-11-09 10:18+0100\n"
"Last-Translator: Esteban I. Ruiz Moreno <exio4.com@gmail.com>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -1838,22 +1838,26 @@ msgstr ""
" /key bindctxt mouse @item(buffer_nicklist):button3 /msg nickserv info "
"${nick}"
-msgid "save/apply/reset layout for buffers and windows"
-msgstr "salva/applica/ripristina il layout per i buffer e le finestre"
+#, fuzzy
+msgid "manage buffers/windows layouts"
+msgstr "gestione dei buffer"
+#, fuzzy
msgid ""
-"save [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
-"|| reset [<name>] [buffers|windows] || rename <name> <new_name>"
+"add [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
+"|| del [<name>] [buffers|windows] || rename <name> <new_name>"
msgstr ""
"save [<nome>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
"|| reset [<nome>] [buffers|windows] || rename <nome> <nuovo_nome>"
+#, fuzzy
msgid ""
-" save: save current layout\n"
+" add: create a layout using the current buffers/windows\n"
" apply: apply saved layout\n"
" leave: leave current layout (does not update any layout)\n"
-" reset: reset buffers and/or windows in a saved layout\n"
-" (if both buffers and windows are reset, the layout is removed)\n"
+" del: delete buffers and/or windows in a saved layout\n"
+" (if neither \"buffers\" nor \"windows\" is given after the name, "
+"the layout is deleted)\n"
" rename: rename a layout\n"
" name: name for saved layout (default is \"default\")\n"
"buffers: save/apply only buffers (order of buffers)\n"
@@ -10349,6 +10353,10 @@ msgstr "Tipo"
msgid "Constants"
msgstr "Costanti"
+#, fuzzy
+#~ msgid "manage layouts for buffers and windows"
+#~ msgstr "salva/applica/ripristina il layout per i buffer e le finestre"
+
#~ msgid "set title for window (terminal for Curses GUI) with name and version"
#~ msgstr ""
#~ "imposta titolo per la finestra (terminale per interfacce Curses) con nome "
diff --git a/po/ja.po b/po/ja.po
index 2fd726c13..3163a5338 100644
--- a/po/ja.po
+++ b/po/ja.po
@@ -20,7 +20,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2013-12-11 21:18+0100\n"
+"POT-Creation-Date: 2013-12-13 12:43+0100\n"
"PO-Revision-Date: 2013-11-09 10:18+0100\n"
"Last-Translator: AYANOKOUZI, Ryuunosuke <i38w7i3@yahoo.co.jp>\n"
"Language-Team: Japanese <https://github.com/l/WeeChat>\n"
@@ -1818,22 +1818,26 @@ msgstr ""
" /key bindctxt mouse @item(buffer_nicklist):button3 /msg nickserv info "
"${nick}"
-msgid "save/apply/reset layout for buffers and windows"
-msgstr "バッファとウィンドウのレイアウトを保存/適用/リセット"
+#, fuzzy
+msgid "manage buffers/windows layouts"
+msgstr "バッファの管理"
+#, fuzzy
msgid ""
-"save [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
-"|| reset [<name>] [buffers|windows] || rename <name> <new_name>"
+"add [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
+"|| del [<name>] [buffers|windows] || rename <name> <new_name>"
msgstr ""
"save [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
"|| reset [<name>] [buffers|windows] || rename <name> <new_name>"
+#, fuzzy
msgid ""
-" save: save current layout\n"
+" add: create a layout using the current buffers/windows\n"
" apply: apply saved layout\n"
" leave: leave current layout (does not update any layout)\n"
-" reset: reset buffers and/or windows in a saved layout\n"
-" (if both buffers and windows are reset, the layout is removed)\n"
+" del: delete buffers and/or windows in a saved layout\n"
+" (if neither \"buffers\" nor \"windows\" is given after the name, "
+"the layout is deleted)\n"
" rename: rename a layout\n"
" name: name for saved layout (default is \"default\")\n"
"buffers: save/apply only buffers (order of buffers)\n"
@@ -10324,6 +10328,10 @@ msgstr "タイプ"
msgid "Constants"
msgstr "定数"
+#, fuzzy
+#~ msgid "manage layouts for buffers and windows"
+#~ msgstr "バッファとウィンドウのレイアウトを保存/適用/リセット"
+
#~ msgid "set title for window (terminal for Curses GUI) with name and version"
#~ msgstr ""
#~ "名前とバージョンを含むウィンドウのタイトルを設定 (Curses GUI 用のターミナ"
diff --git a/po/pl.po b/po/pl.po
index 21a466667..34ba02d0b 100644
--- a/po/pl.po
+++ b/po/pl.po
@@ -21,7 +21,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2013-12-11 21:18+0100\n"
+"POT-Creation-Date: 2013-12-13 12:43+0100\n"
"PO-Revision-Date: 2013-11-11 09:07+0100\n"
"Last-Translator: Krzysztof Korościk <soltys@szluug.org>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -1862,22 +1862,26 @@ msgstr ""
" /key bindctxt mouse @item(buffer_nicklist):button3 /msg nickserv info "
"${nick}"
-msgid "save/apply/reset layout for buffers and windows"
-msgstr "zapisz/zatwierdź/zresetuj układ buforów i okien"
+#, fuzzy
+msgid "manage buffers/windows layouts"
+msgstr "zarządzaj buforami"
+#, fuzzy
msgid ""
-"save [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
-"|| reset [<name>] [buffers|windows] || rename <name> <new_name>"
+"add [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
+"|| del [<name>] [buffers|windows] || rename <name> <new_name>"
msgstr ""
"save [<nazwa>] [buffers|windows] || apply [<nazwa>] [buffers|windows]|| "
"leave || reset [<nazwa>] [buffers|windows] || rename <nazwa> <nowa_nazwa>"
+#, fuzzy
msgid ""
-" save: save current layout\n"
+" add: create a layout using the current buffers/windows\n"
" apply: apply saved layout\n"
" leave: leave current layout (does not update any layout)\n"
-" reset: reset buffers and/or windows in a saved layout\n"
-" (if both buffers and windows are reset, the layout is removed)\n"
+" del: delete buffers and/or windows in a saved layout\n"
+" (if neither \"buffers\" nor \"windows\" is given after the name, "
+"the layout is deleted)\n"
" rename: rename a layout\n"
" name: name for saved layout (default is \"default\")\n"
"buffers: save/apply only buffers (order of buffers)\n"
@@ -10523,3 +10527,7 @@ msgstr "Typ"
msgid "Constants"
msgstr "Stałe"
+
+#, fuzzy
+#~ msgid "manage layouts for buffers and windows"
+#~ msgstr "zapisz/zatwierdź/zresetuj układ buforów i okien"
diff --git a/po/pt_BR.po b/po/pt_BR.po
index ba7a686f0..7849d45d5 100644
--- a/po/pt_BR.po
+++ b/po/pt_BR.po
@@ -21,7 +21,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2013-12-11 21:18+0100\n"
+"POT-Creation-Date: 2013-12-13 12:43+0100\n"
"PO-Revision-Date: 2013-11-09 10:18+0100\n"
"Last-Translator: Sergio Durigan Junior <sergiosdj@gmail.com>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -1781,22 +1781,26 @@ msgstr ""
" restaurar a associação padrão para a tecla alt-r:\n"
" /key reset meta-r"
-msgid "save/apply/reset layout for buffers and windows"
-msgstr "salvar/aplicar/resetar a disposição dos buffers e janelas"
+#, fuzzy
+msgid "manage buffers/windows layouts"
+msgstr "gerenciar buffers"
+#, fuzzy
msgid ""
-"save [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
-"|| reset [<name>] [buffers|windows] || rename <name> <new_name>"
+"add [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
+"|| del [<name>] [buffers|windows] || rename <name> <new_name>"
msgstr ""
"save [<nome>] [buffers|windows] || apply [<nome>] [buffers|windows] || leave "
"|| reset [<nome>] [buffers|windows] || rename <nome> <novo_nome>"
+#, fuzzy
msgid ""
-" save: save current layout\n"
+" add: create a layout using the current buffers/windows\n"
" apply: apply saved layout\n"
" leave: leave current layout (does not update any layout)\n"
-" reset: reset buffers and/or windows in a saved layout\n"
-" (if both buffers and windows are reset, the layout is removed)\n"
+" del: delete buffers and/or windows in a saved layout\n"
+" (if neither \"buffers\" nor \"windows\" is given after the name, "
+"the layout is deleted)\n"
" rename: rename a layout\n"
" name: name for saved layout (default is \"default\")\n"
"buffers: save/apply only buffers (order of buffers)\n"
@@ -9569,6 +9573,10 @@ msgstr ""
msgid "Constants"
msgstr ""
+#, fuzzy
+#~ msgid "manage layouts for buffers and windows"
+#~ msgstr "salvar/aplicar/resetar a disposição dos buffers e janelas"
+
#~ msgid "set title for window (terminal for Curses GUI) with name and version"
#~ msgstr ""
#~ "define o título para a janela (terminal para a interface Curses) com nome "
diff --git a/po/ru.po b/po/ru.po
index 55fcc12a5..67711292e 100644
--- a/po/ru.po
+++ b/po/ru.po
@@ -21,7 +21,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2013-12-11 21:18+0100\n"
+"POT-Creation-Date: 2013-12-13 12:43+0100\n"
"PO-Revision-Date: 2013-11-09 10:18+0100\n"
"Last-Translator: Aleksey V Zapparov AKA ixti <ixti@member.fsf.org>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -1548,20 +1548,22 @@ msgstr ""
" reset: сбросить клавиши на значения по умолчанию и удалить ВСЕ личные "
"привязки (используйте внимательно!)"
-msgid "save/apply/reset layout for buffers and windows"
-msgstr ""
+#, fuzzy
+msgid "manage buffers/windows layouts"
+msgstr "управление буферами"
msgid ""
-"save [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
-"|| reset [<name>] [buffers|windows] || rename <name> <new_name>"
+"add [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
+"|| del [<name>] [buffers|windows] || rename <name> <new_name>"
msgstr ""
msgid ""
-" save: save current layout\n"
+" add: create a layout using the current buffers/windows\n"
" apply: apply saved layout\n"
" leave: leave current layout (does not update any layout)\n"
-" reset: reset buffers and/or windows in a saved layout\n"
-" (if both buffers and windows are reset, the layout is removed)\n"
+" del: delete buffers and/or windows in a saved layout\n"
+" (if neither \"buffers\" nor \"windows\" is given after the name, "
+"the layout is deleted)\n"
" rename: rename a layout\n"
" name: name for saved layout (default is \"default\")\n"
"buffers: save/apply only buffers (order of buffers)\n"
diff --git a/po/tr.po b/po/tr.po
index f19277daf..bc440c883 100644
--- a/po/tr.po
+++ b/po/tr.po
@@ -20,7 +20,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2013-12-11 21:18+0100\n"
+"POT-Creation-Date: 2013-12-13 12:43+0100\n"
"PO-Revision-Date: 2013-11-09 10:13+0100\n"
"Last-Translator: Hasan Kiran <sunder67@hotmail.com>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -1373,22 +1373,24 @@ msgid ""
"${nick}"
msgstr ""
-msgid "save/apply/reset layout for buffers and windows"
+msgid "manage buffers/windows layouts"
msgstr ""
+#, fuzzy
msgid ""
-"save [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
-"|| reset [<name>] [buffers|windows] || rename <name> <new_name>"
+"add [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
+"|| del [<name>] [buffers|windows] || rename <name> <new_name>"
msgstr ""
"save [<isim>] [buffers|windows] || apply [<isim>] [buffers|windows] || leave "
"|| reset [<isim>] [buffers|windows] || rename <isim> <yeni_isim>"
msgid ""
-" save: save current layout\n"
+" add: create a layout using the current buffers/windows\n"
" apply: apply saved layout\n"
" leave: leave current layout (does not update any layout)\n"
-" reset: reset buffers and/or windows in a saved layout\n"
-" (if both buffers and windows are reset, the layout is removed)\n"
+" del: delete buffers and/or windows in a saved layout\n"
+" (if neither \"buffers\" nor \"windows\" is given after the name, "
+"the layout is deleted)\n"
" rename: rename a layout\n"
" name: name for saved layout (default is \"default\")\n"
"buffers: save/apply only buffers (order of buffers)\n"
diff --git a/po/weechat.pot b/po/weechat.pot
index 53a9373cf..67a2f68cb 100644
--- a/po/weechat.pot
+++ b/po/weechat.pot
@@ -21,7 +21,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat 0.4.1-dev\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2013-12-11 21:18+0100\n"
+"POT-Creation-Date: 2013-12-13 12:43+0100\n"
"PO-Revision-Date: 2013-02-14 18:20+0100\n"
"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -1379,20 +1379,21 @@ msgid ""
"${nick}"
msgstr ""
-msgid "save/apply/reset layout for buffers and windows"
+msgid "manage buffers/windows layouts"
msgstr ""
msgid ""
-"save [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
-"|| reset [<name>] [buffers|windows] || rename <name> <new_name>"
+"add [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || leave "
+"|| del [<name>] [buffers|windows] || rename <name> <new_name>"
msgstr ""
msgid ""
-" save: save current layout\n"
+" add: create a layout using the current buffers/windows\n"
" apply: apply saved layout\n"
" leave: leave current layout (does not update any layout)\n"
-" reset: reset buffers and/or windows in a saved layout\n"
-" (if both buffers and windows are reset, the layout is removed)\n"
+" del: delete buffers and/or windows in a saved layout\n"
+" (if neither \"buffers\" nor \"windows\" is given after the name, "
+"the layout is deleted)\n"
" rename: rename a layout\n"
" name: name for saved layout (default is \"default\")\n"
"buffers: save/apply only buffers (order of buffers)\n"
diff --git a/src/core/wee-command.c b/src/core/wee-command.c
index 1cbf1feee..e7342ff47 100644
--- a/src/core/wee-command.c
+++ b/src/core/wee-command.c
@@ -3350,7 +3350,7 @@ command_layout_display_tree (struct t_gui_layout_window *layout_window,
}
/*
* Gets arguments for /layout command (if option is save/apply/reset).
*/
void
@@ -3438,8 +3438,8 @@ COMMAND_CALLBACK(layout)
return WEECHAT_RC_OK;
}
- /* save layout */
- if (string_strcasecmp (argv[1], "save") == 0)
+ /* add a layout */
+ if (string_strcasecmp (argv[1], "add") == 0)
{
command_layout_get_arguments (argc, argv, &layout_name, &ptr_layout,
&flag_buffers, &flag_windows);
@@ -3498,8 +3498,8 @@ COMMAND_CALLBACK(layout)
return WEECHAT_RC_OK;
}
- /* reset layout */
- if (string_strcasecmp (argv[1], "reset") == 0)
+ /* delete layout */
+ if (string_strcasecmp (argv[1], "del") == 0)
{
command_layout_get_arguments (argc, argv, &layout_name, &ptr_layout,
&flag_buffers, &flag_windows);
@@ -6829,28 +6829,28 @@ command_init ()
" || missing %(keys_contexts)",
&command_key, NULL);
hook_command (NULL, "layout",
- N_("save/apply/reset layout for buffers and windows"),
- N_("save [<name>] [buffers|windows]"
+ N_("manage buffers/windows layouts"),
+ N_("add [<name>] [buffers|windows]"
" || apply [<name>] [buffers|windows]"
" || leave"
- " || reset [<name>] [buffers|windows]"
+ " || del [<name>] [buffers|windows]"
" || rename <name> <new_name>"),
- N_(" save: save current layout\n"
+ N_(" add: create a layout using the current buffers/windows\n"
" apply: apply saved layout\n"
" leave: leave current layout (does not update any layout)\n"
- " reset: reset buffers and/or windows in a saved layout\n"
- " (if both buffers and windows are reset, the "
- "layout is removed)\n"
+ " del: delete buffers and/or windows in a saved layout\n"
+ " (if neither \"buffers\" nor \"windows\" is given "
+ "after the name, the layout is deleted)\n"
" rename: rename a layout\n"
" name: name for saved layout (default is \"default\")\n"
"buffers: save/apply only buffers (order of buffers)\n"
"windows: save/apply only windows (buffer displayed by "
"each window)\n\n"
"Without argument, this command displays saved layouts."),
- "save %(layouts_names)|buffers|windows buffers|windows"
+ "add %(layouts_names)|buffers|windows buffers|windows"
" || apply %(layouts_names)|buffers|windows buffers|windows"
" || leave"
- " || reset %(layouts_names)|buffers|windows buffers|windows"
+ " || del %(layouts_names)|buffers|windows buffers|windows"
" || rename %(layouts_names) %(layouts_names)",
&command_layout, NULL);
hook_command (NULL, "mouse",
@@ -3350,7 +3350,7 @@ command_layout_display_tree (struct t_gui_layout_window *layout_window,
}
/*
- * Gets arguments for /layout command (if option is save/apply/reset).
+ * Gets arguments for /layout command (if option is add/apply/del).
*/
void